# ResSimpy: Python API for working with Reservoir Simulator models

[![License](https://img.shields.io/pypi/l/ressimpy)](https://github.com/bp/ResSimpy/blob/master/LICENSE.MD)
[![Documentation Status](https://readthedocs.org/projects/ResSimpy/badge/?version=latest)](https://ResSimpy.readthedocs.io/en/latest/?badge=latest)
[![Python CI](https://github.com/bp/ResSimpy/actions/workflows/ci-tests.yml/badge.svg)](https://github.com/bp/ResSimpy/actions/workflows/ci-tests.yml)
![Python version](https://img.shields.io/pypi/pyversions/ResSimpy)
[![PyPI](https://img.shields.io/pypi/v/ResSimpy)](https://badge.fury.io/py/ResSimpy)
![Status](https://img.shields.io/pypi/status/ResSimpy)
[![codecov](https://codecov.io/gh/bp/ResSimpy/branch/master/graph/badge.svg)](https://codecov.io/gh/bp/ResSimpy)

## Introduction
**ResSimpy** is a Python API for automating reservoir simulation workflows, allowing the user to read, manipulate and 
write reservoir simulation input decks. Whilst it was created by staff at BP, we welcome contributions from anybody 
interested, whether it is by raising pull requests, or simply suggesting features / raising bugs in the GitHub issues.

### Documentation

See the complete package documentation on
[readthedocs](https://ResSimpy.readthedocs.io/).

## Installation

ResSimpy can be installed with pip:

```bash
pip install ressimpy
```

## Contributing

Please see [Contributing Guide](docs/CONTRIBUTING.rst) for instructions on how to set up a dev environment and contribute
code to the project.